@@ -6,14 +6,13 @@ from .parser import Parser
 
 
 class RegexRule(Parser):
-    matching_rule = models.ForeignKey('MatchingRule', related_name='regex_rules')
+    matching_rule = models.ForeignKey(
+        "MatchingRule", on_delete=models.CASCADE, related_name="regex_rules"
+    )
     regex = models.TextField(null=False)
 
     def __str__(self):
-        return '{} match {}'.format(
-            self.method(),
-            self.regex
-        )
+        return "{} match {}".format(self.method(), self.regex)
 
     def is_matching(self, obj):
         """
